@@ -19,7 +19,8 @@ rr=Ker(rr)
 if (cv) diag(rr)=0
 if (is.null(w)) w<-rep(1,ncol(rr))
 rr<-sweep(rr,2,w,FUN="*")   ## antes un 2
-res=rr/apply(rr,1,sum,na.rm=TRUE)
+#res=rr/apply(rr,1,sum,na.rm=TRUE)
+res=rr/rowSums(rr,na.rm=TRUE)
 return(res)
 }
 
